require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of Contract
    module Contract

      # DTO for setAttributes command of Contract.
      class ContractSetAttributes < UU::OS::REST::DTO

        # Name of the financial transaction.<br>
        # @param [String]
        # @return [String]
        attr_accessor :name

        # UESURI of account from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :account_from_opposite_territory_uri

        # Amount of the Financial Transaction without vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # Specifies which side controls transaction (CREDIT or DEBIT).
        # @param [String]
        # @return [String]
        attr_accessor :control_side

        # Number of credit account.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # UESURI of credit business case from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_from_opposite_territory_uri

        # UESURI of the credit business case
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_uri

        # Description for credit side.
        # @param [String]
        # @return [String]
        attr_accessor :credit_description

        # UESUI of credit company.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_company_uri

        # Credit vat date of the transaction.
        attr_accessor :credit_vat_date

        # Number of debit account.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # UESURI of debit business case from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_from_opposite_territory_uri

        # UESURI of the debit business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_uri

        # Description for debit side.
        # @param [String]
        # @return [String]
        attr_accessor :debit_description

        # UESURI of credit company
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_company_uri

        # Debit vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :debit_vat_date

        # vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :vat_date

        # Date the payment is due to be paid.
        # @param [String, Time]
        # @return [String]
        attr_accessor :due_date

        # Date the payment is expected to be payed to.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Type of financial transaction. Item from enumeration {@link FinancialTransactionType} <br>
        # @param [FinancialTransactionType]
        # @return [FinancialTransactionType]
        attr_accessor :financial_transaction_type

        # Invoice number of financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # Pay date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :pay_date

        # Date of invoicing to the counterparty.
        # @param [String, Time]
        # @return [String]
        attr_accessor :protocol_date

        # Probability of payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Specific symbol.
        # @param [String, Time]
        # @return [String]
        attr_accessor :specific_symbol

        # Default Income Item Code.
        # @param [String]
        # @return [String]
        attr_accessor :default_income_item_code

        # Default Cost Item Code
        # @param [String]
        # @return [String]
        attr_accessor :default_cost_item_code

        # Code of currency.
        # @param [String]
        # @return [String]
        attr_accessor :currency

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # UESURI of credit financial category for payment
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_credit_financial_category_uri

        # UESURI of debit financial category for payment
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_debit_financial_category_uri

        # UESURI of credit financial category for fast payment
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :fast_payment_credit_financial_category_uri

        # UESURI of debit financial category for fast payment
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :fast_payment_debit_financial_category_uri

        # UESURI of credit financial category for credit note
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_credit_financial_category_uri

        # UESURI of debit financial category for credit note
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_debit_financial_category_uri

        # UESURI of credit financial category for expost
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_credit_financial_category_uri

        # UESURI of debit financial category for expost
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_debit_financial_category_uri

        # UESURI of credit financial category for transfer
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_credit_financial_category_uri

        # UESURI of debit financial category for transfer
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_debit_financial_category_uri

        # UESURI of accept payment executive role
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :accept_payment_executive_role_uri

        # UESURI of request payment competent role
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :request_payment_competent_role_uri

        # UESURI of request payment executive role
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :request_payment_executive_role_uri

        # UESURI of confirm payment competent role
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :confirm_payment_competent_role_uri

        # UESURI of confirm payment executive role
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :confirm_payment_executive_role_uri


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end


        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end


        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end


        def control_side
          attributes[:controlSide]
        end

        def control_side=(val)
          attributes[:controlSide] = val
        end


        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end


        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end


        def credit_business_case_from_opposite_territory_uri
          attributes[:creditBusinessCaseFromOppositeTerritoryUri]
        end

        def credit_business_case_from_opposite_territory_uri=(val)
          if val
            attributes[:creditBusinessCaseFromOppositeTerritoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseFromOppositeTerritoryUri] = nil
          end
        end


        def credit_business_case_uri
          attributes[:creditBusinessCaseUri]
        end

        def credit_business_case_uri=(val)
          if val
            attributes[:creditBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseUri] = nil
          end
        end


        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end


        def credit_company_uri
          attributes[:creditCompanyUri]
        end

        def credit_company_uri=(val)
          if val
            attributes[:creditCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditCompanyUri] = nil
          end
        end


        def credit_vat_date
          attributes[:creditVatDate]
        end

        def credit_vat_date=(val)
          attributes[:creditVatDate] = val
        end


        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end


        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end


        def debit_business_case_from_opposite_territory_uri
          attributes[:debitBusinessCaseFromOppositeTerritoryUri]
        end

        def debit_business_case_from_opposite_territory_uri=(val)
          if val
            attributes[:debitBusinessCaseFromOppositeTerritoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseFromOppositeTerritoryUri] = nil
          end
        end


        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end


        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end


        def debit_company_uri
          attributes[:debitCompanyUri]
        end

        def debit_company_uri=(val)
          if val
            attributes[:debitCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitCompanyUri] = nil
          end
        end


        def debit_vat_date
          attributes[:debitVatDate]
        end

        def debit_vat_date=(val)
          attributes[:debitVatDate] = val
        end


        def vat_date
          attributes[:vatDate]
        end

        def vat_date=(val)
          attributes[:vatDate] = val
        end


        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end


        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end


        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end


        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end


        def pay_date
          attributes[:payDate]
        end

        def pay_date=(val)
          attributes[:payDate] = val
        end


        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end


        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end


        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end


        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end


        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end


        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end


        def payment_credit_financial_category_uri
          attributes[:paymentCreditFinancialCategoryUri]
        end

        def payment_credit_financial_category_uri=(val)
          if val
            attributes[:paymentCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:paymentCreditFinancialCategoryUri] = nil
          end
        end


        def payment_debit_financial_category_uri
          attributes[:paymentDebitFinancialCategoryUri]
        end

        def payment_debit_financial_category_uri=(val)
          if val
            attributes[:paymentDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:paymentDebitFinancialCategoryUri] = nil
          end
        end


        def fast_payment_credit_financial_category_uri
          attributes[:fastPaymentCreditFinancialCategoryUri]
        end

        def fast_payment_credit_financial_category_uri=(val)
          if val
            attributes[:fastPaymentCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:fastPaymentCreditFinancialCategoryUri] = nil
          end
        end


        def fast_payment_debit_financial_category_uri
          attributes[:fastPaymentDebitFinancialCategoryUri]
        end

        def fast_payment_debit_financial_category_uri=(val)
          if val
            attributes[:fastPaymentDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:fastPaymentDebitFinancialCategoryUri] = nil
          end
        end


        def credit_note_credit_financial_category_uri
          attributes[:creditNoteCreditFinancialCategoryUri]
        end

        def credit_note_credit_financial_category_uri=(val)
          if val
            attributes[:creditNoteCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditNoteCreditFinancialCategoryUri] = nil
          end
        end


        def credit_note_debit_financial_category_uri
          attributes[:creditNoteDebitFinancialCategoryUri]
        end

        def credit_note_debit_financial_category_uri=(val)
          if val
            attributes[:creditNoteDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditNoteDebitFinancialCategoryUri] = nil
          end
        end


        def expost_credit_financial_category_uri
          attributes[:expostCreditFinancialCategoryUri]
        end

        def expost_credit_financial_category_uri=(val)
          if val
            attributes[:expostCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:expostCreditFinancialCategoryUri] = nil
          end
        end


        def expost_debit_financial_category_uri
          attributes[:expostDebitFinancialCategoryUri]
        end

        def expost_debit_financial_category_uri=(val)
          if val
            attributes[:expostDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:expostDebitFinancialCategoryUri] = nil
          end
        end


        def transfer_credit_financial_category_uri
          attributes[:transferCreditFinancialCategoryUri]
        end

        def transfer_credit_financial_category_uri=(val)
          if val
            attributes[:transferCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:transferCreditFinancialCategoryUri] = nil
          end
        end


        def transfer_debit_financial_category_uri
          attributes[:transferDebitFinancialCategoryUri]
        end

        def transfer_debit_financial_category_uri=(val)
          if val
            attributes[:transferDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:transferDebitFinancialCategoryUri] = nil
          end
        end



        def accept_payment_executive_role_uri
          attributes[:acceptPaymentExecutiveRoleUri]
        end

        def accept_payment_executive_role_uri=(val)
          if val
            attributes[:acceptPaymentExecutiveRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:acceptPaymentExecutiveRoleUri] = nil
          end
        end


        def request_payment_competent_role_uri
          attributes[:requestPaymentCompetentRoleUri]
        end

        def request_payment_competent_role_uri=(val)
          if val
            attributes[:requestPaymentCompetentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:requestPaymentCompetentRoleUri] = nil
          end
        end


        def request_payment_executive_role_uri
          attributes[:requestPaymentExecutiveRoleUri]
        end

        def request_payment_executive_role_uri=(val)
          if val
            attributes[:requestPaymentExecutiveRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:requestPaymentExecutiveRoleUri] = nil
          end
        end


        def confirm_payment_competent_role_uri
          attributes[:confirmPaymentCompetentRoleUri]
        end

        def confirm_payment_competent_role_uri=(val)
          if val
            attributes[:confirmPaymentCompetentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:confirmPaymentCompetentRoleUri] = nil
          end
        end


        def confirm_payment_executive_role_uri
          attributes[:confirmPaymentExecutiveRoleUri]
        end

        def confirm_payment_executive_role_uri=(val)
          if val
            attributes[:confirmPaymentExecutiveRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:confirmPaymentExecutiveRoleUri] = nil
          end
        end

                def account_from_opposite_territory_uri
                   attributes[:accountFromOppositeTerritoryUri]
                end

                def account_from_opposite_territory_uri=(val)
                  if val
                    attributes[:accountFromOppositeTerritoryUri] = UU::OS::UESURI.new(val)
                    else
                     attributes[:accountFromOppositeTerritoryUri] = nil
                    end
                end

                def default_income_item_code
                 attributes[:defaultIncomeItemCode]
                end

                def default_income_item_code=(val)
                 attributes[:defaultIncomeItemCode] = val
                end

                def default_cost_item_code
                 attributes[:defaultIncomeItemCode]
                end

                def default_cost_item_code=(val)
                 attributes[:defaultCostItemCode] = val
                end


      end
    end
  end
end

